package multex; //AssertionFailure.java

//History:
//2001-04-19  Knabe  Now as standalone class AssertionFailure
//2000-09-29  Knabe  Creation as inner class of Assertion

/**Indicates that an assertion failed. An assertion should always be true.
  Any failing of an assertion thus has to be considered as a programming error.
  You should use assertions for indicating the violation of invariants or
  postconditions. For indicating the violation of a precondition you should
  better use an individually named subclass of {@link multex.Exc}.
*/
public class AssertionFailure extends multex.Failure {

  /**Creates an AssertionFailure object, detail description here. For more
    convenient creation you can use the convenience constructors with 0..10
    unnamed parameters of type Object. If all diagnostic parameters of the
    assertion are Object-s, i.e. of non-primitive types, it is still more
    convenient to call {@link Assertion#check(boolean, String, Object[])}
    or one of its convenience wrappers.
    @param i_name The condition, which failed, as a String
    @param i_parameters A polymorphic array of additional diagnostic parameters, e.g. values of variables in the assertion condition
  */
  public AssertionFailure(String i_name, Object[] i_parameters)
  {
    super("Failure of assertion " + i_name,
      (Exception)null, i_parameters
    );
  }

  /**Convenience constructor null.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(final String i_name){this(i_name,null);}

  /**Convenience constructor 0.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(String i_name, Object i_par0)
  {this(i_name, new Object[]{i_par0});}

  /**Convenience constructor 1.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(String i_name, Object i_par0, Object i_par1)
  {this(i_name, new Object[]{i_par0,i_par1});}

  /**Convenience constructor 2.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(String i_name, Object i_par0, Object i_par1, Object i_par2)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2});}

  /**Convenience constructor 3.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3});}

  /**Convenience constructor 4.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4});}

  /**Convenience constructor 5.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4, Object i_par5)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4,i_par5});}

  /**Convenience constructor 6.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4, Object i_par5, Object i_par6)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4,i_par5,i_par6
  });}

  /**Convenience constructor 7.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4, Object i_par5, Object i_par6, Object i_par7)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4,i_par5,i_par6,
  i_par7});}

  /**Convenience constructor 8.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4, Object i_par5, Object i_par6, Object i_par7,
    Object i_par8
  ){this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4,i_par5,i_par6,
  i_par7,i_par8});}

  /**Convenience constructor 9.
    @see #AssertionFailure(String, Object[])
  */
  public AssertionFailure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4, Object i_par5, Object i_par6, Object i_par7,
    Object i_par8, Object i_par9
  ){this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4,i_par5,i_par6,
  i_par7,i_par8,i_par9});}

}//AssertionFailure
