package multex; //MultexException.java

//2001-04-14  Knabe  No longer using public non-static attributes as parameters
//2000-10-06  Knabe  Creation

/**Marks an exception as to be handled especially by MsgText. A MultexException
  has indexed parameters as a polymorphic Object[], which can be inserted into
  the message text by directives {0} to {9}. Subclasses should provide a
  constructor with an Object[] of up to 10 elements and convenience constructors
  with up to 10 individual parameters of type Object.
  See <A HREF="http://java.sun.com/j2se/1.3/docs/api/java/text/MessageFormat.html">
  *java.text.MessageFormat</A>.
*/

public interface MultexException {


/**Returns the default message text pattern for this exception object or null.
  Inserting the exception parameters into the message text pattern is
  done by class {@link MsgText}.
  Locale specific message text patterns are handled by MsgText, too.
*/
String getDefaultMessageTextPattern();

/**Returns true, if the exception parameter array exits and has at least one
 * element.*/
boolean hasParameters();

/**Returns a copy of the exception parameters.*/
Object[] getParameters();

/**
  Returns all user-provided information contained in the exception object
  in an internal, but human readable format. The information are the default
  message text pattern and
  the exception parameters of this object or null if none of these is provided.
  E.g.:
  <PRE>
  *  TEXT: Unable to create file {0} in directory {1}
  *  {0}=myfile.dat  {1}=C:\temp\data
  </PRE>
  Overrides the same method of
  <A HREF="http://java.sun.com/j2se/1.3/docs/api/java/lang/Throwable.html">java.lang.Throwable</A>
*/
public String getMessage();

}